# Config.pm - Settings file for generator (IPTables Firewall Configuration).
# Created by James A. Pattie.  Copyright (c) 2001-2004, Xperience, Inc.

package PCXFireWall::Config;

use strict;
use vars qw ($AUTOLOAD @ISA @EXPORT $VERSION);

require Exporter;
@ISA = qw(Exporter AutoLoader);
@EXPORT = qw();

$VERSION = "2.23";

sub new
{
  my $that = shift;
  my $class = ref($that) || $that;
  my $self = bless {}, $class;

  # Installation path
  $self->{installPath} = "/etc/pcx-firewall";  # This does not need the trailing /.

  # Log Prefix
  $self->{logPrefix} = "FW";

  $self->{preComment} = ""; # comments to put before and after the rule.
  $self->{postComment} = "";

  # network command to use
  $self->{networkCommand} = "ifconfig";  # valid values will be ifconfig or ip

  return $self;
}

sub AUTOLOAD
{
  my $self = shift;
  my $type = ref($self) || die "$self is not an object";
  my $name = $AUTOLOAD;
  $name =~ s/.*://;	# strip fully-qualified portion
  unless (exists $self->{$name})
  {
    die "Can't access `$name' field in object of class $type";
  }
  if (@_)
  {
    return $self->{$name} = shift;
  }
  else
  {
    return $self->{$name};
  }
}

1;
__END__

=head1 NAME

Config - The PCXFireWall Configuration Object.

=head1 SYNOPSIS

  use PCXFireWall::Config;
  my $obj = PCXFireWall::Config->new;

=head1 DESCRIPTION

Config is the Configuration Object for the PCXFireWall.

=head1 FUNCTIONS

  scalar new(void)
    Creates a new instance of the PCXFireWall::Config
    object.

=head1 VARIABLES

  installPath - The location that the install script will put the files.
                Defaults to /etc/pcx-firewall.  The trailing / is not
                required.

  logPrefix - Default header prepended to the log message to display.
               Defaults to 'FW'.

  preComment - Allows you to specify the default comment before the rule.

  postComment - Allows you to specify the default comment after the rule.

  networkCommand - Allows you to specify what command should be used
                   to determine the dynamic IP address of a dynamic
                   interface.  This is also used to determine broadcast
                   address values as well.

                   Valid values are ifconfig or ip.

  NOTE:  All data fields are accessible by specifying the object
         and pointing to the data member to be modified on the
         left-hand side of the assignment.
         Ex.  $obj->variable($newValue); or $value = $obj->variable;

=head1 AUTHOR

Xperience, Inc. (mailto:admin at pcxperience.com)

=head1 SEE ALSO

perl(1)

=cut
